require 'spec_helper'
require 'middleman_spec_helper'

require 'branchable_cdn_assets/middleman/rake_tasks'

describe BranchableCDNAssets::Middleman::RakeTasks do

  describe "::register" do

    before :each do
      Given.fixture 'base'
      Rake::Task.clear
    end

    after :each do
      Given.cleanup!
    end

    it "adds tasks under provided namespace" do
      described_class.register(:test)

      expect( Rake::Task.tasks.map(&:to_s) ).to include 'test:list'
    end

    it "defaults to :cdn for namespace" do
      described_class.register

      expect( Rake::Task.tasks.map(&:to_s) ).to include 'cdn:list'
    end

    it "sends method with check to the file_manager" do
      class FileManagerStub
        extend BranchableCDNAssets::CheckBefore

        def list *args
          []
        end

        def pull!
        end
      end

      file_manager_double = FileManagerStub.new
      allow_any_instance_of( described_class ).to receive(:file_manager).and_return( file_manager_double )

      expect( file_manager_double ).to receive(:list)
      expect( file_manager_double ).to receive(:pull!)

      described_class.register
      Rake::Task['cdn:list'].invoke
      Rake::Task['cdn:pull'].invoke
    end

  end

end